@@ -1,16 +1,19 @@
 """Transformers that calculate Doc2Vec embeddings using GenSim."""
+from __future__ import annotations
+
 import logging
 from collections.abc import Iterable
+from typing import Any, List, Union
 
 import numpy as np
-from gensim.models.doc2vec import Doc2Vec, TaggedDocument
-from sklearn.base import BaseEstimator, TransformerMixin
+from gensim.models.doc2vec import Doc2Vec, TaggedDocument  # type: ignore
+from sklearn.base import BaseEstimator, TransformerMixin  # type: ignore
 
-logging.getLogger('gensim').setLevel(logging.WARNING)
-logging.getLogger('gensim').propagate = False
+logging.getLogger("gensim").setLevel(logging.WARNING)
+logging.getLogger("gensim").propagate = False
 
 
-def _sanity_check(documents):
+def _sanity_check(documents: List[List[str]]) -> None:
     """
     Check data for basic properties.
 
@@ -18,10 +21,10 @@ def _sanity_check(documents):
     representing sentences.
     """
     if len(documents) < 1:
-        raise ValueError('empty document set provided')
+        raise ValueError("empty document set provided")
 
     if type(documents[0]) == str or not isinstance(documents[1], Iterable):
-        raise TypeError('this transformer only works on pre-split data.')
+        raise TypeError("this transformer only works on pre-split data.")
 
 
 class Doc2VecTransformer(TransformerMixin, BaseEstimator):
@@ -37,14 +40,14 @@ class Doc2VecTransformer(TransformerMixin, BaseEstimator):
 
     def __init__(
         self,
-        learning_rate=0.02,
-        epochs=20,
-        vector_size=100,
-        alpha=0.025,
-        min_alpha=0.00025,
-        min_count=2,
-        dm=1,
-        workers=1,
+        learning_rate: float = 0.02,
+        epochs: int = 20,
+        vector_size: int = 100,
+        alpha: float = 0.025,
+        min_alpha: float = 0.00025,
+        min_count: int = 2,
+        distributed_memory: int = 1,
+        workers: int = 1,
     ):
         """
         Initialize Doc2Vec Transformer.
@@ -56,7 +59,7 @@ class Doc2VecTransformer(TransformerMixin, BaseEstimator):
             alpha: alpha of the gensim model
             min_alpha: min_alpha of the gensim model
             min_count: min number of occurrences for each word
-            dm: whether to use distributed memory model or not
+            distributed_memory: whether to use distributed memory model or not
             workers: number of threads
         """
         self.learning_rate = learning_rate
@@ -65,7 +68,7 @@ class Doc2VecTransformer(TransformerMixin, BaseEstimator):
         self.alpha = alpha
         self.min_alpha = min_alpha
         self.min_count = min_count
-        self.dm = dm
+        self.distributed_memory = distributed_memory
         self.workers = workers
 
         self.model = Doc2Vec(
@@ -73,33 +76,32 @@ class Doc2VecTransformer(TransformerMixin, BaseEstimator):
             alpha=alpha,
             min_alpha=min_alpha,
             min_count=min_count,
-            dm=dm,
+            dm=distributed_memory,
             workers=workers,
         )
 
-    def fit(self, documents, labels=None, **fit_params):
+    def fit(
+        self,
+        documents: List[List[str]],
+        labels: Union[List[str], np.array] = None,
+        **fit_params: Any
+    ) -> Doc2VecTransformer:
         """Fit the model by learning the training corpus."""
-        documents = [
-            [str(x) for x in document]
-            for document in documents
-        ]
+        documents = [[str(x) for x in document] for document in documents]
 
         _sanity_check(documents)
         tagged_x = [
-            TaggedDocument(words=row, tags=[])
-            for _, row in enumerate(documents)
+            TaggedDocument(words=row, tags=[]) for _, row in enumerate(documents)
         ]
         self.model.build_vocab(tagged_x)
-        self.model.train(tagged_x, total_examples=self.model.corpus_count,
-                         epochs=self.epochs)
+        self.model.train(
+            tagged_x, total_examples=self.model.corpus_count, epochs=self.epochs
+        )
         return self
 
-    def transform(self, documents):
+    def transform(self, documents: List[List[str]]) -> np.array:
         """Infer the vectors for documents."""
-        documents = [
-            [str(x) for x in document]
-            for document in documents
-        ]
+        documents = [[str(x) for x in document] for document in documents]
         _sanity_check(documents)
         vectors = [self.model.infer_vector(doc) for doc in documents]
         return np.array(vectors)
